@@ -56,7 +56,7 @@ class Message:
 
 
 class NodeWire:
-    def __init__(self, node_name='node', server='cloud1.nodewire.org', process=None):
+    def __init__(self, node_name='node', server='secure.nodewire.org', process=None):
         self.name = node_name
         self.type = node_name
         self.server_address = server
